@@ -8,7 +8,7 @@ use warnings;
 use utf8;
 no warnings 'utf8';
 use diagnostics;
-use Sub::Exporter -setup => {exports => [qw(parseExcel openCiscoPort portManager writePortConfig)]};
+use Sub::Exporter -setup => {exports => [qw(parseExcel openCiscoPort openH3cPort portManager writePortConfig)]};
 
 #------------------------------------------------------------------------------
 # 加载扩展模块
@@ -131,7 +131,7 @@ sub openCiscoPort {
   # 如果是网络设备同时生成双边交换机配置
   if ($is_network =~ /Y|是/i) {
     if ($is_aggr =~ /Y|是/i and !!$aggr_id) {
-      push @{$cfg2}, "interface port-channel$aggr_id";
+      push @{$cfg2}, "interface port-channel $aggr_id";
       push @{$cfg2}, "  description TO_" . ($sn1 // $device1) . "_" . ($iface1 // $ip1);
       push @{$cfg2}, "  no shutdown";
 
@@ -183,7 +183,7 @@ sub openCiscoPort {
 
   # 正常情况只关注交换机侧的配置
   if ($is_aggr =~ /Y|是/i and !!$aggr_id) {
-    push @{$cfg1}, "interface port-channel$aggr_id";
+    push @{$cfg1}, "interface port-channel $aggr_id";
     push @{$cfg1}, "  description TO_" . ($sn2 // $device2) . "_" . ($iface2 // $ip2);
     push @{$cfg1}, "  no shutdown";
 
@@ -240,6 +240,165 @@ sub openCiscoPort {
   return ([$port1, $port2]);
 }
 
+#------------------------------------------------------------------------------
+# 生成华三交换机端口配置
+#------------------------------------------------------------------------------
+sub openH3cPort {
+  my $data = shift;
+
+  # A端设备信息
+  my $device1 = $data->{device1};
+  my $mgmt1   = $data->{mgmt1};
+  my $sn1     = $data->{sn1};
+  my $iface1  = $data->{iface1};
+  my $ip1     = $data->{ip1};
+
+  # B端设备信息
+  my $device2 = $data->{device2};
+  my $mgmt2   = $data->{mgmt2};
+  my $sn2     = $data->{sn2};
+  my $iface2  = $data->{iface2};
+  my $ip2     = $data->{ip2};
+
+  # 接口通用属性
+  my $is_aggr  = $data->{is_aggr};
+  my $aggr_id  = $data->{aggr_id};
+  my $is_trunk = $data->{is_trunk};
+  my $vlan_id  = $data->{vlan_id};
+  my $is_l3    = $data->{is_l3};
+
+  # 是否网络设备 网络设备需要同时生成 AB端 交换机的配置
+  my $is_network = $data->{is_network};
+
+  # 初始化变量
+  my ($cfg1, $cfg2);
+
+  # CELL 填写成员端口可能有多个
+  my $i = 0;
+  my $j = 0;
+
+  # 物理口实际配置
+  my @iface1 = split(/,|;/, $iface1);
+  my @iface2 = split(/,|;/, $iface2);
+
+  # 早期异常拦截
+  return if $is_l3 and $ip1 and $ip2;
+  return unless @iface1;
+  return unless @iface2;
+  return if @iface1 != @iface2;
+
+  # 如果是网络设备同时生成双边交换机配置
+  if ($is_network =~ /Y|是/i) {
+    if ($is_aggr =~ /Y|是/i and !!$aggr_id) {
+      push @{$cfg2}, "interface Bridge-Aggregation $aggr_id";
+      push @{$cfg2}, "  description TO_" . ($sn1 // $device1) . "_" . ($iface1 // $ip1);
+      push @{$cfg2}, "  undo shutdown";
+
+      if ($is_l3 =~ /Y|是/i and !!$ip2) {
+        push @{$cfg2}, "  no switchport";
+        push @{$cfg2}, "  ip address $ip2";
+      }
+      else {
+        my $vlans = join(",", split(/,|;/, $vlan_id));
+        push @{$cfg2}, "  spanning-tree port type network";
+        if ($is_trunk =~ /Y|是/i) {
+          push @{$cfg2}, "  port link-type trunk";
+          push @{$cfg2}, "  port trunk permit vlan $vlans" if !!$vlans;
+        }
+        else {
+          push @{$cfg2}, "  port link-type access";
+          push @{$cfg2}, "  port access vlan $vlan_id";
+        }
+      }
+    }
+
+    # 物理口实际配置
+    foreach my $iface (@iface2) {
+      push @{$cfg2}, "interface $iface";
+      push @{$cfg2}, "  description TO_" . ($sn1 // $device1) . "_" . $iface1[$i];
+      push @{$cfg2}, "  port link-aggregation group $aggr_id" if $is_aggr and $aggr_id;
+      push @{$cfg2}, "  undo shutdown";
+
+      if ($is_l3 =~ /Y|是/i and !!$ip2) {
+        push @{$cfg2}, "  no switchport";
+        push @{$cfg2}, "  ip address $ip2" unless $is_aggr and $aggr_id;
+      }
+      else {
+        push @{$cfg2}, "  spanning-tree port type network";
+        my $vlans = join(",", split(/,|;/, $vlan_id));
+        if ($is_trunk =~ /Y|是/i) {
+          push @{$cfg2}, "  port link-type trunk";
+          push @{$cfg2}, "  port trunk permit vlan $vlans" if !!$vlans;
+        }
+        else {
+          push @{$cfg2}, "  port link-type access";
+          push @{$cfg2}, "  port access vlan $vlan_id";
+        }
+      }
+      push @{$cfg2}, "!";
+      $i++;
+    }
+  }
+
+  # 正常情况只关注交换机侧的配置
+  if ($is_aggr =~ /Y|是/i and !!$aggr_id) {
+    push @{$cfg1}, "interface Bridge-Aggregation $aggr_id";
+    push @{$cfg1}, "  description TO_" . ($sn2 // $device2) . "_" . ($iface2 // $ip2);
+    push @{$cfg1}, "  undo shutdown";
+
+    if ($is_l3 =~ /Y|是/i and !!$ip1) {
+      push @{$cfg1}, "  no switchport";
+      push @{$cfg1}, "  ip address $ip1";
+    }
+    else {
+      my $vlans = join(",", split(/,|;/, $vlan_id));
+      push @{$cfg1}, "  spanning-tree port type network";
+      if ($is_trunk =~ /Y|是/i) {
+        push @{$cfg1}, "  port link-type trunk";
+        push @{$cfg1}, "  port trunk permit vlan $vlans" if !!$vlans;
+      }
+      else {
+        push @{$cfg1}, "  port link-type access";
+        push @{$cfg1}, "  port access vlan $vlan_id";
+      }
+    }
+  }
+
+  # 物理口实际配置
+  foreach my $iface (@iface1) {
+    push @{$cfg1}, "interface $iface";
+    push @{$cfg1}, "  description TO_" . ($sn2 // $device2) . "_" . $iface2[$j];
+    push @{$cfg1}, "  port link-aggregation group $aggr_id" if $is_aggr and $aggr_id;
+    push @{$cfg1}, "  undo shutdown";
+
+    if ($is_l3 =~ /Y|是/i and !!$ip1) {
+      push @{$cfg1}, "  no switchport";
+      push @{$cfg1}, "  ip address $ip1" unless $is_aggr and $aggr_id;
+    }
+    else {
+      push @{$cfg1}, "  spanning-tree port type network";
+      my $vlans = join(",", split(/,|;/, $vlan_id));
+      if ($is_trunk =~ /Y|是/i) {
+        push @{$cfg1}, "  port link-type trunk";
+        push @{$cfg1}, "  port trunk permit vlan  $vlans" if !!$vlans;
+      }
+      else {
+        push @{$cfg1}, "  port link-type access";
+        push @{$cfg1}, "  port access vlan $vlan_id";
+      }
+    }
+    push @{$cfg1}, "#";
+    $j++;
+  }
+
+  # 返回计算结果
+  my $index1 = $device1 . "-" . $mgmt1;
+  my $index2 = $device2 . "-" . $mgmt2;
+  my $port1  = $cfg1                   ? [$index1, $cfg1] : undef;
+  my $port2  = ($is_network and $cfg2) ? [$index2, $cfg2] : undef;
+  return ([$port1, $port2]);
+}
+
 #------------------------------------------------------------------------------
 # 自动读取 EXCEL 并结构化输出端口配置
 #------------------------------------------------------------------------------
